<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package NRG_Event
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="format-detection" content="telephone=no" />
<meta name="apple-mobile-web-app-capable" content="yes" />
<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1.0, user-scalable=no, minimal-ui"/>
<?php wp_head(); ?>
</head>

<?php
	$color =  ( cs_get_option( 'nrgevent_colors')  ) ? cs_get_option( 'nrgevent_colors') : 'yellow';
?>

<body <?php body_class(); ?> data-color="<?php print esc_attr( $color ); ?>">
	
<?php if ( cs_get_option( 'show_preloader' ) ) {   ?>
	<!-- LOADER -->
	<div id="loading">
		<div id="loading-center">
				<div id="loading-center-absolute">
					<div class="bigSqr">
						<div class="square first"></div>
						<div class="square second"></div>
						<div class="square third"></div>
						<div class="square fourth"></div>
					</div>
				</div>
		</div>
		<div id="loading-text"><?php esc_html_e('Loading','nrgevent'); ?></div>
	</div>
<?php } ?>

<!-- HEADER -->
<?php
$class_header = 'static ';
if ( cs_get_option( 'nrg_site_type' ) == 'onepage' ) {
	if ( cs_get_option( 'enable-sticky-menu' ) && is_page() ) {
		$class_header = 'fixed ';
	} 
} else {
	if ( cs_get_option( 'enable-sticky-menu' ) && is_page() ) {
		$class_header = 'fixed ';
	} 
}

$nrg_header_type = cs_get_option( 'nrg_header_type'); ?>
<header class="header <?php echo esc_attr( $class_header . $nrg_header_type ); ?>">
	<div class="container">
		<?php if ($nrg_header_type == 'type-3') { ?>
		<div class="top-line clearfix"></div>
		<?php } ?>

		<div class="logo-block">
			<?php 
			$nrgevent_type_logo = cs_get_option( 'type_logo');
			$nrgevent_logo_text = cs_get_option( 'logo_text');
			$nrgevent_logo_image = cs_get_option( 'logo_image');
			?>
			<a class="logo" href="<?php echo esc_url(home_url( '/' )); ?>">
				<?php if ($nrgevent_type_logo == 'image' ) {
					if(!empty($nrgevent_logo_image)){
					?>
						<img class="f-logo" src="<?php echo esc_attr( $nrgevent_logo_image ); ?>" alt="<?php echo esc_attr( get_bloginfo("name") ); ?>">
					<?php
					} else {
						esc_html_e('Add image logo','nrgevent');
					}
				} else { ?>
				<span class="logo-text">
					<?php
						if(!empty($nrgevent_logo_text)){
							echo esc_html($nrgevent_logo_text);
						} else {
							esc_html_e('NRGevent','nrgevent');
						}
					?>
				</span>
			<?php } ?>
			</a>
		</div>
		<nav class="main-nav">
			<?php if ($nrg_header_type == 'type-3') { ?>
			<div class="top-line-left">
						<?php
						$nrg_header_email = cs_get_option( 'nrg_header_email');
						if (!empty($nrg_header_email)) { ?>
						<div class="top-contact"><i class="fa fa-envelope-o"></i><a href="mailto:<?php echo esc_attr( $nrg_header_email ); ?>"><?php echo esc_html( $nrg_header_email ); ?></a></div>
						<?php } ?>

						<?php 
						$nrg_header_tel = cs_get_option( 'nrg_header_tel');
						if (!empty($nrg_header_tel)) { ?>
							<div class="top-contact">
								<i class="fa fa-phone"></i>
								<?php foreach ($nrg_header_tel as $tel) { ?>
								<a href="tel:<?php echo esc_url( $tel['tel'] ); ?>"><?php echo esc_html( $tel['tel'] ); ?></a> 
								<?php } ?>
							</div>

						<?php }  //endif  ?>

			</div> 
			<?php } ?>

			<?php
			if( has_nav_menu( 'primary' )){

				$args_menu = array(
					'theme_location'  => 'primary',
					'container'       => '',
					'container_class' => '',
					'menu_class'      => 'anchor-navigation',
					'depth'           => 3,
					'walker'          => new Nrgevent_Menu_Walker()
				);

				wp_nav_menu( $args_menu );

			} elseif (!has_nav_menu( 'primary' )) { ?>
						
				<div class="nav-item no_register_menu">
					<?php esc_html_e('Please register Menu from ','nrgevent');?>
					<a href="<?php echo esc_url(admin_url('nav-menus.php')); ?>" target="_blank"><?php esc_html_e('Appearance &gt; Menus','nrgevent');?></a>
				</div>

			<?php } //endif ?>
			
			<?php if ($nrg_header_type == 'type-3') { ?>
			<div class="top-line-right">

				<?php $nrg_header_social = cs_get_option( 'nrg_header_social');?>
				<?php if (!empty($nrg_header_social)) { ?>
					<div class="top-social">
						<?php foreach ($nrg_header_social as $social) { ?>
								<a href="<?php echo esc_url( $social['link'] ); ?>"><i class="<?php echo esc_attr( $social['social_icon'] ); ?>"></i></a>
						<?php } // endforeach ?>
					</div>
				<?php } //endif ?>

				<?php if ( cs_get_option( 'nrg_header_show_search') ) { ?>
					<a class="search-link top-search" href="#"><i class="fa fa-search"></i></a>
					<div class="search-popup custom-popup">
						<form action="<?php echo esc_url(home_url( '/' )); ?>">
								<div class="popup-close"><i class="fa fa-times"></i></div>
								<h3 class="popup-title text-center"><?php esc_html_e('Search','nrgevent'); ?></h3>
								<div class="c-form-group">
									<div class="c-form-label"><?php esc_html_e('Enter search text','nrgevent'); ?></div>
									<input type="text" name="s" required="" value="">
								</div>
								<input class="c-btn b-50 black hv-yellow-o" type="submit" value="<?php esc_attr_e('Search','nrgevent'); ?>">
						</form>
					</div>
				<?php } ?>
			</div>
			<?php } // end type 3 ?>
		</nav>
		<button class="cmn-toggle-switch"><span></span></button>
	</div>
</header>