<?php
/**
 * NRG Event config functions.
 *
 * @package NRG_Event
*/


// after setup theme
if ( ! function_exists( 'nrgevent_after_setup' ) ) {
  /**
   * Sets up theme defaults and registers support for various WordPress features.
   *
   * Note that this function is hooked into the after_setup_theme hook, which
   * runs before the init hook. The init hook is too late for some features, such
   * as indicating support for post thumbnails.
   */
  function nrgevent_after_setup() {

    load_theme_textdomain( 'nrgevent', get_template_directory() . '/languages' );

    add_image_size('slider_speaker_mini',150, 100, true );
    add_image_size('slider_speaker_thumb',200, 121, true );
    add_image_size('slider_speaker_full',800, 700, true );

    add_image_size('slider_simple_image',370, 212, true );

    add_image_size('gallery_image_big',540, 430, true );
    add_image_size('gallery_image_middle',576, 216, true );
    add_image_size('gallery_image_mini',281, 218, true );


    add_theme_support('custom-background' );
    add_theme_support('automatic-feed-links' );
    add_theme_support('custom-header');
    add_theme_support('post-thumbnails' );
    add_theme_support('title-tag' );


    // This theme uses wp_nav_menu() in one location.
    register_nav_menus( array(
      'primary' => esc_html__( 'Primary Menu', 'nrgevent' ),
    ) );

    /*
     * Switch default core markup for search form, comment form, and comments
     * to output valid HTML5.
     */
    add_theme_support( 'html5', array(
      'search-form',
      'comment-form',
      'comment-list',
      'gallery',
      'caption',
    ) );

    /*
     * Enable support for Post Formats.
     * See https://developer.wordpress.org/themes/functionality/post-formats/
     */
    add_theme_support( 'post-formats', array(
      'aside',
      'audio',
      'image',
      'video',
      'quote',
      'link',
    ) );

    // Set up the WordPress core custom background feature.
    add_theme_support( 'custom-background', apply_filters( 'nrgevent_custom_background_args', array(
      'default-color' => 'ffffff',
      'default-image' => '',
    ) ) );
  }
  
}
add_action( 'after_setup_theme', 'nrgevent_after_setup' );



/**
 * Define base plugins TGM Plugin Activation
 */
require_once get_template_directory() . '/inc/plugins/tgm/class-tgm-plugin-activation.php';
if ( ! function_exists( 'nrgevent_include_required_plugins' ) ) {
  function nrgevent_include_required_plugins() {

    $plugins = array(

      array(
        'name'                => esc_html__('Contact Form 7','nrgevent'), // The plugin name
        'slug'                => 'contact-form-7', // The plugin slug (typically the folder name)
        'required'            => false, // If false, the plugin is only 'recommended' instead of required
        'version'             => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
        'force_activation'    => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
        'force_deactivation'  => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
        'external_url'        => '', // If set, overrides default API URL and points to an external URL
      ),
      array(
        'name'                => esc_html__('Contact Form DB','nrgevent'), // The plugin name
        'slug'                => 'contact-form-7-to-database-extension', // The plugin slug (typically the folder name)
        'required'            => false, // If false, the plugin is only 'recommended' instead of required
        'version'             => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
        'force_activation'    => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
        'force_deactivation'  => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
        'external_url'        => '', // If set, overrides default API URL and points to an external URL
      ),
      array(
        'name'                => esc_html__('Visual Composer','nrgevent'), // The plugin name
        'slug'                => 'js_composer', // The plugin slug (typically the folder name)
        'required'            => true, // If false, the plugin is only 'recommended' instead of required
        'version'             => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
        'force_activation'    => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
        'force_deactivation'  => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
        'source'              => 'http://demo.nrgthemes.com/projects/plugins/js_composer.zip', // If set, overrides default API URL and points to an external URL
      ),

      array(
        'name'                => esc_html__('NRG Event Plugins','nrgevent'), // The plugin name
        'slug'                => 'nrgevent-plugins', // The plugin slug (typically the folder name)
        'required'            => true, // If false, the plugin is only 'recommended' instead of required
        'version'             => '1.3.0', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
        'force_activation'    => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
        'force_deactivation'  => true, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
        'source'              => NRG_EVENT_T_PATH . '/inc/plugins/nrgevent-plugins.zip', // If set, overrides default API URL and points to an external URL
       ),   


    );

    // Change this to your theme text domain, used for internationalising strings

    /**
     * Array of configuration settings. Amend each line as needed.
     * If you want the default strings to be available under your own theme domain,
     * leave the strings uncommented.
     * Some of the strings are added into a sprintf, so see the comments at the
     * end of each line for what each argument will be.
     */
    $config = array(
        'domain'          => 'nrgevent',                   // Text domain - likely want to be the same as your theme.
        'default_path'    => '',                          // Default absolute path to pre-packaged plugins
        'menu'            => 'tgmpa-install-plugins',     // Menu slug
        'has_notices'       => true,                        // Show admin notices or not
        'is_automatic'      => false,             // Automatically activate plugins after installation or not
        'message'       => '',              // Message to output right before the plugins table
        'strings'         => array(
          'page_title'                            => esc_html__( 'Install Required Plugins', 'nrgevent' ),
          'menu_title'                            => esc_html__( 'Install Plugins', 'nrgevent' ),
          'installing'                            => esc_html__( 'Installing Plugin: %s', 'nrgevent' ), // %1$s = plugin name
          'oops'                                  => esc_html__( 'Something went wrong with the plugin API.', 'nrgevent' ),
          'notice_can_install_required'           => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'nrgevent' ), // %1$s = plugin name(s)
          'notice_can_install_recommended'      => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'nrgevent' ), // %1$s = plugin name(s)
          'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'nrgevent' ), // %1$s = plugin name(s)
          'notice_can_activate_required'          => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'nrgevent' ), // %1$s = plugin name(s)
          'notice_can_activate_recommended'     => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'nrgevent' ), // %1$s = plugin name(s)
          'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'nrgevent' ), // %1$s = plugin name(s)
          'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'nrgevent' ), // %1$s = plugin name(s)
          'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'nrgevent' ), // %1$s = plugin name(s)
          'install_link'                  => _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'nrgevent' ),
          'activate_link'                 => _n_noop( 'Activate installed plugin', 'Activate installed plugins', 'nrgevent' ),
          'return'                                => esc_html__( 'Return to Required Plugins Installer', 'nrgevent' ),
          'plugin_activated'                      => esc_html__( 'Plugin activated successfully.', 'nrgevent' ),
          'complete'                  => esc_html__( 'All plugins installed and activated successfully. %s', 'nrgevent' ), // %1$s = dashboard link
          'nag_type'                  => 'updated' // Determines admin notice type - can only be 'updated' or 'error'
        )
      );

    tgmpa( $plugins, $config );

  }
}
add_action( 'tgmpa_register', 'nrgevent_include_required_plugins' );


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
if ( ! function_exists( 'nrgevent_content_width' ) ) {
  function nrgevent_content_width() {
    $GLOBALS['content_width'] = apply_filters( 'nrgevent_content_width', 1200 );
  }
}
add_action( 'after_setup_theme', 'nrgevent_content_width', 0 );


/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
if ( ! function_exists( 'nrgevent_widgets_init' ) ) {
  function nrgevent_widgets_init() {
    register_sidebar( array(
      'name'          => esc_html__( 'Sidebar', 'nrgevent' ),
      'id'            => 'sidebar-1',
      'description'   => '',
      'before_widget' => '<aside id="%1$s" class="widget %2$s">',
      'after_widget'  => '</aside>',
      'before_title'  => '<h2 class="widget-title">',
      'after_title'   => '</h2>',
    ) );
  }
}
add_action( 'widgets_init', 'nrgevent_widgets_init' );


/**
 * Enqueue scripts and styles.
 */
if ( ! function_exists( 'nrgevent_scripts' ) ) {
  function nrgevent_scripts() {

    wp_enqueue_style( 'bootstrap',        get_template_directory_uri() . '/assets/css/bootstrap.min.css');
    wp_enqueue_style( 'font-awesome',     get_template_directory_uri() . '/assets/css/font-awesome.min.css');
    wp_enqueue_style( 'idangerous.swiper',    get_template_directory_uri() . '/assets/css/idangerous.swiper.css');
    wp_enqueue_style( 'change-color',       get_template_directory_uri() . '/assets/css/change_color.css');
    wp_enqueue_style( 'base-style',       get_template_directory_uri() . '/assets/css/style.css');
    wp_enqueue_style( 'dynamic-css', admin_url('admin-ajax.php').'?action=dynamic_css', '', '1.2');

    wp_enqueue_style( 'nrgevent-style',       get_stylesheet_uri() );

    wp_enqueue_script( 'nrgevent_idangerous_swiper', get_template_directory_uri() . '/assets/js/idangerous.swiper.min.js', array('jquery'), '20150115', true );
    wp_enqueue_script( 'nrgevent_isotope', get_template_directory_uri() . '/assets/js/isotope.pkgd.min.js', array('jquery'), '20150115', true );
    wp_enqueue_script( 'nrgevent_imagelightbox', get_template_directory_uri() . '/assets/js/imagelightbox.min.js', array('jquery'), '20150115', true );
    wp_enqueue_script( 'nrgevent_classycountdown', get_template_directory_uri() . '/assets/js/jquery.classycountdown.min.js', array('jquery'), '20150115', true );
    wp_enqueue_script( 'nrgevent_knob', get_template_directory_uri() . '/assets/js/jquery.knob.js', array('jquery'), '20150115', true );
    wp_enqueue_script( 'nrgevent_throttle', get_template_directory_uri() . '/assets/js/jquery.throttle.js', array('jquery'), '20150115', true ); 
    wp_enqueue_script( 'nrgevent_maps', 'http://maps.googleapis.com/maps/api/js?key=' . esc_html( cs_get_option( 'google_map_api_key' ) ), array(), '', true );
    wp_enqueue_script( 'nrgevent_global', get_template_directory_uri() . '/assets/js/global.js', array('jquery'), '20150115', true );
    wp_enqueue_script( 'nrgevent_anchors_navigation', get_template_directory_uri() . '/assets/js/anchors.navigation.js', array('jquery'), '20150115', true );
    wp_enqueue_script( 'nrgevent_navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), '20120206', true );

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
      wp_enqueue_script( 'comment-reply' );
    }

    // add TinyMCE style
    add_editor_style();
  }
}
add_action( 'wp_enqueue_scripts', 'nrgevent_scripts', 1 );


// support svg mime types
if ( ! function_exists( 'nrgevent_mime_types' ) ) {
  function nrgevent_mime_types($mimes) {
    $mimes['svg'] = 'image/svg+xml';
    return $mimes;
  }
}
add_filter('upload_mimes', 'nrgevent_mime_types');


// cs framework missing
if (! function_exists('cs_get_option')) {
   function cs_get_option(){
    return '';
   }
}

if ( ! function_exists( 'cs_get_customize_option' ) ) {
   function cs_get_customize_option(){
    return '';
   }
}

// filter style link
if ( ! function_exists( 'nrgevent_style_loader_tag_function' ) ) {
  function nrgevent_style_loader_tag_function($tag){
    //do stuff here to find and replace the rel attribute
    $tag = preg_replace("/media=''/", "", $tag);
    $tag = preg_replace("/rel='stylesheet'/", "rel='stylesheet' property='stylesheet'", $tag);
    return $tag;
  }
}
add_filter('style_loader_tag', 'nrgevent_style_loader_tag_function');

if ( ! function_exists( 'nrgevent_comment' ) ) {
  function nrgevent_comment( $comment, $args, $depth ) {
     $GLOBALS['comment'] = $comment;  ?>

     <div class="comment-entry" id="comment-<?php comment_ID(); ?>" <?php comment_class('news-comments'); ?>>
      <div class="left no-padding ava">
        <?php echo get_avatar( $comment, '80' ); ?>
        <p class="name"><?php echo get_comment_author_link(); ?></p>
      </div>
      <div class="right">
        <?php if ($comment->comment_approved == '0') : ?>
                 <div class="alert alert-info">
                    <p><?php esc_html_e( 'Your comment is awaiting moderation.','nrgevent' ) ?></p>
                 </div>
              <?php endif; ?>
              <?php $comment_text = get_comment_text();
          $trimmed = trim($comment_text, " ");
          echo wpautop($trimmed);
        ?>
        <p class="yellow"><?php printf( '%3$s', esc_url( get_comment_link( $comment->comment_ID ) ), get_comment_time( 'c' ), sprintf( get_comment_date(), get_comment_time() )); ?></p>
        <p><?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))); ?></p>
      </div>
  <?php
  }
}