<?php 
/**
 * NRG Event helper functions.
 *
 * @package NRG_Event
*/


// functions max word in string
if (!function_exists('nrgevent_maxsite_str_word')) {
  function nrgevent_maxsite_str_word($text, $counttext = 10, $sep = ' ') {
      $words = explode($sep, $text);
      if ( count($words) > $counttext )
          $text = join($sep, array_slice($words, 0, $counttext));
      return $text;
  }
}

// for oembed
if (!function_exists('nrgevent_get_oEmbedContent')) {
  function nrgevent_get_oEmbedContent( $content, $array = false )
  {

    $all_urls = wp_extract_urls( $content );

    if ($array) {
      $content = array();
    }

    foreach ($all_urls as $key=>$value) {
      $embed = wp_oembed_get($value);
      if ($array) {
        $content[] = $embed;
      } else {
        $content = str_replace($value, $embed,$content);
      }
    }

    return $content;
  }
}


if (!function_exists('nrgevent_the_content')) {

    function nrgevent_the_content($limit,$read_more) {
      $content = explode(' ', get_the_content(), $limit);
      if (count($content)>=$limit) {
        array_pop($content);
        $read_more = '<a class="more-link" href="' . esc_url(get_permalink()) . '">'. $read_more . '</a>';
        $content = implode(" ",$content). '<br>' .$read_more;
      } else {
        $content = implode(" ",$content);
      }
      $content = preg_replace('/\[.+\]/','', $content);
      $content = apply_filters('the_content', $content);
      return $content;
    }
}


/**
 * 
 * TOP MENU. Top Menu Walker. Changes the view of top navigation
 *
 */
class Nrgevent_Menu_Walker extends Walker_Nav_Menu
{ 
  function display_element( $element, &$children_elements, $max_depth, $depth=0, $args, &$output ) 
  {
        $element->has_children = !empty( $children_elements[$element->ID] );
        
        if(!empty($element->classes)){
          $element->classes[] = ( $element->current || $element->current_item_ancestor ) ? 'active' : '';
          $element->classes[] = ( $element->has_children ) ? 'page-dropdown' : '';         
        }
    
        parent::display_element( $element, $children_elements, $max_depth, $depth, $args, $output );
    }
    
  function start_lvl( &$output, $depth = 0, $args = array() ) {
    $indent = str_repeat("\t", $depth);
    $output .= "\n$indent <i class=\"fa fa-angle-down\"></i><ul class=\"dopwown-menu\">\n";
  }
    
  function start_el(&$output, $item, $depth = 0, $args = array(), $id = 0)
  {

    $item_output = '';
    $indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
    $class_names = $value = '';
        $classes = empty( $item->classes ) ? array() : (array) $item->classes;
        $classes[] = 'nav-item menu-item-'. $item->ID;
        $class_names = join( ' ', apply_filters( 'nav-item', array_filter( $classes ), $item, $args ) );
        $class_names = ' class="' . esc_attr( $class_names ) . '"';
    $output.= $indent.'<li id="menu-item-'. $item->ID.'" '.$class_names.'>';
    
    if ( empty( $item->title ) && empty( $item->url )) 
    {
      $item->url = get_permalink($item->ID);
      $item->title = $item->post_title;
      
      $attributes = $this->attributes($item);

      $item_output .= '<a'. $attributes .'>';
      $item_output .= apply_filters( 'the_title', $item->title, $item->ID );
      $item_output .= '</a>';
    }
    else
    {


      $attributes = $this->attributes($item);

      //onepage options
      $site_type = cs_get_option( 'nrg_site_type' );
      $favorite_page = cs_get_option( 'nrg_favorite_page' );

      $site_type = cs_get_option( 'nrg_site_type'); //if onepage option ON

      $site_type = ($site_type == 'onepage') ? true : false;
      
      $nrg_favorite_page = cs_get_option( 'nrg_favorite_page'); //Get selectet pages

      
      
      //Get this slug
      $post = get_post($item->object_id);
      $slug = $post->post_name;
      
      //Get page id by slug
      $pageid = get_page_by_path($slug);

      if ($pageid) {
        $page_id = $pageid->ID;
      } else {
        $page_id = '';
      }
      
      //check if this page add to onepage
      if ($nrg_favorite_page !== false && is_array($nrg_favorite_page)) {
          $key = array_search($page_id, $nrg_favorite_page);
      } else {
          $key = '';
      }

      //cleated menu URL
      $page_for_posts = get_option( 'page_for_posts' );
      if ($key !== false && $site_type && $post && $post->ID != $page_for_posts){
        $newattr = ' href="'.site_url().'/#'.$slug.'" class="anchor-scroll"';
      } else {
        $newattr = $attributes;
      }
      // end onepage options

      $item_output = $args->before;
      $item_output .= '<a'. $newattr .'>';
      $item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
      $item_output .= '</a>';
      $item_output .= $args->after;
    }
    
    $output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args, $id );
  }
  
  private function attributes($item)
  {
    $attributes  = ! empty( $item->attr_title ) ? ' title="'  . esc_attr( $item->attr_title ) .'"' : '';
    $attributes .= ! empty( $item->target )     ? ' target="' . esc_attr( $item->target     ) .'"' : '';
    $attributes .= ! empty( $item->xfn )        ? ' rel="'    . esc_attr( $item->xfn        ) .'"' : '';
    $attributes .= ! empty( $item->url )        ? ' href="'   . esc_attr( $item->url        ) .'"' : '';
    
    return $attributes;
  }
  
  public static function items_default_wrap($menu_text) {
    /**
     * Set default menu for menus not yet linked to theme location
     * Method courtesy of robertomatute - https://github.com/roots/roots/issues/939
     */
    return str_replace('<ul>', '<ul class="right">', $menu_text);
  }
      
  public static function items_remove_defaut_wrapper() 
  {
    /**
     * Remove default div wrapper around ul element
     */
    ?>
    <script type="text/javascript">
      jQuery(document).ready(function($){
        var default_nav = $(".top-bar-section > div > ul");
        if(default_nav.parent("div").hasClass("right") === true){
          default_nav.unwrap();
        }
      });
    </script>
    <?php
  }
}



