<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package NRG_Event
 */
get_header(); 

//titles blog
$blog_title = cs_get_option( 'blog_title' );
$blog_subtitle = cs_get_option('blog_subtitle');
$blog_desc = cs_get_option('blog_desc');

// show/hide sidebar
$show_sidebar = cs_get_option('show_sidebar');
if ($show_sidebar === true) {
	$base_column = ' col-md-12';
} else {
	$base_column = 'col-md-9 is_sidebar base-content';
	$right_column = 'col-md-3 is_sidebar base-sidebar';
}

//blog_posts_per_row
$blog_posts_per_row_tablets = cs_get_option('blog_posts_per_row_tablets');
if (empty($blog_posts_per_row_tablets)) {
	$blog_posts_per_row_tablets = 'col-xs-12 col-sm-6';
}
$blog_posts_per_row = cs_get_option('blog_posts_per_row');
if (empty($blog_posts_per_row)) {
	$blog_posts_per_row = 'col-md-4';
}
?>

<div class="container blog no_vc">
	<?php if ( is_home() && ((!empty($blog_title))) || (!empty($blog_desc)) ) { ?>
		<div class="block-header">

			<?php if(!empty($blog_subtitle)){ ?>
				<h4 class="block-category"><?php echo esc_html($blog_subtitle); ?></h4>
			<?php } ?>

			<?php if(!empty($blog_title)){ ?>
				<h2 class="block-title"><?php echo esc_html($blog_title); ?></h2>
			<?php } else { ?>
				<h2 class="block-title"><?php single_post_title(); ?></h2>
			<?php } ?>
			
			<?php if ( is_home() && (!empty($blog_desc)) ) { ?>
			<div class="block-text"><?php echo wp_kses_post(do_shortcode($blog_desc)); ?></div>
			<?php } ?>
		</div>
	<?php } ?>

	<div class="blog-list clearfix">
		<div class="row">
			<div class="<?php echo esc_attr( $base_column );?>  clearfix">
				<?php if ( have_posts() ) { ?>
				<div class="blog-row row isotope-container">
					<div class="grid-sizer item-333"></div>
					<?php
					// Start the loop.
					while ( have_posts() ) {

						the_post();

						// get post format
						$format = get_post_format();
						$format = ( $format === false) ? 'default' : $format;
						$classes_post =  $blog_posts_per_row_tablets  . ' ' . $blog_posts_per_row . ' container single-page no_vc format-' . get_post_format() . ' blog-content-item';
						?>
						<article <?php post_class( esc_attr($classes_post) ); ?> >
							<?php 
							if( is_sticky() ){  ?>
							<i title="<?php esc_html_e( 'Sticky Post', 'nrgevent' ); ?>" class="sticky-icon fa fa-thumb-tack fa-2x"></i>
							<?php }
							// get template format
							get_template_part('template-parts/content', $format);
							?>
						</article>
						<?php

					} // End the loop.

				?>
				</div>
				<?php

				// Previous/next page navigation.
				the_posts_pagination( array(
					'mid_size'           => 1,
					'prev_text'          => esc_html__( 'Previous page','nrgevent'),
					'next_text'          => esc_html__( 'Next page','nrgevent' ),
					'screen_reader_text' => ' ',
				));

					// If no content, include the "No posts found" template.
				} else {
					get_template_part( 'template-parts/content', 'none' );
				}
				?>
				
			</div>
			<?php if($show_sidebar !== true){ ?>
			<div class="<?php echo esc_attr($right_column);?>">
				<?php get_sidebar(); ?>
			</div>
			<?php } ?>
		</div>
	</div>
</div>

<?php get_footer();